@@ -8,6 +8,10 @@ use MRO::Compat;
 use Carp 'confess';
 use Scalar::Util 'blessed', 'weaken';
 
+our $VERSION   = '0.84';
+$VERSION = eval $VERSION;
+our $AUTHORITY = 'cpan:STEVAN';
+
 sub meta {
     my $self = shift;
 
